%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script for calculating quadratic force   coefficients%
% of a SWATH, specific for design made by Swathdesign.m%
%------------------------------------------------------%
% input:                                               %
%      HxP- height of pontoon as function of x-position%
%      WxP- Width of pontoon as function of x position %
%      x  - x-positions of sections of SWATH           %
%------------------------------------------------------%
% output:                                              %
%         Bq- Diagonal quadratic force matrix          %
%             Coupled terms neglected , given in       %
%             kN s^2/m^2 and kNs^2/m                   %
%         Cdx- Drag coefficient in x direction         %
%         Cdy- Drag coefficient in y direction         %
%         Cdz- Drag coefficient in z direction         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Heine Groetting                              %
%------------------------------------------------------%
% Last edit: 02/06-2015                                %
%------------------------------------------------------%
a=1;
rho=1.025;
[HxP WxP x]=Swathdesign(a);
Bq=zeros(6,6);
dx=abs(x(1)-x(2));
Nsec=length(x);
L=x(Nsec)-x(1);
HxPm=max(HxP);
WxPm=max(WxP);
Cd1=0.1; %%% Drag coefficients from CENGEL and CIMBALA 2010
Cd2=1.2;
Cd3=1.1;
Bq(1,1)=2*(WxPm*0.35*0.4+HxPm*WxPm)*Cd1*0.5*rho;
Bq(2,2)=2*(L*2.6)*Cd2*0.5*rho; 
    for j=1:Nsec
        B33(j)=dx*Cd3*WxP(j)*0.5*rho*2;
        B55(j)=dx*abs(x(j)^3)*WxP(j)*Cd3*0.5*rho*2;
    end
    Bq(3,3)=sum(B33);
    Bq(5,5)=sum(B55);
Cdx=Bq(1,1)/24
Cdy=Bq(2,2)/24
Cdz=Bq(3,3)/24

