%-------------------------------------------------------------%
% availability.m                                              %
%-------------------------------------------------------------%
% Function that calculates the availability for a given LHS   %
% with respect to weather data stored in wavedat.dat          %
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 17/03-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
%  LHS_TMA     - Matrix containing limiting significant       % 
%                waveheight as function of peak frequency     %
%                and wave heading calculated by use of the    % 
%                TMA spectrum                                 %
%  LHS_JON     - Same as LHS_TMA but with use of the JONSWAP  %
%                spectrum instead                             %
%  wavedat.dat - Wave data for Dogger Bank location 2         % 
%-------------------------------------------------------------%
% Output:                                                     %
% avblty_TMA   - Availability with use of the JONSWAP spectrum%
% avblty_JON   - Availability with use of the JONSWAP spectrum%
% avblty_TMA_W - Availibilty in December, January             %
%                    February,  Mars                          %
% avblty_JON_W - Availibilty in December, January             %
%                    February,  Mars                          %
% TMA_vector   - Vector of length Nseas containg 1 if the     %
%                    seastate was ok and 0 if not             %
%-------------------------------------------------------------%



function [avblty_TMA avblty_JON avblty_JON_W avblty_TMA_W TMA_vector]=availabily(LHS_TMA,LHS_JON)
A=load('wavedat.dat'); % A becomes a matrix containing the wave data
Hs=A(:,1); % Vector containing the signinficant waveheights 
Tp=A(:,2);  % Vector containing the peak periods
Mdir=A(:,3); % Vector containing the mean direction
HsS=A(:,4); % Vector containing the significant waveheight of swell part of waves
TpS=A(:,5);  % Vector containing the the peak periods of swell
MdirS=A(:,6); % Mean direction of swell
HsW=A(:,7); % Vector containing the significant waveheight of windsea
TpW=A(:,8); % Vector containing the peak periods of wind sea
MdirW=A(:,9); % Mean direction of windsea
month=A(:,10); % Month of record 
l=length(Hs);
JONteller=0;
TMAteller=0;
Wteller=0;
JONWteller=0;
TMAWteller=0;

for i=1:l
    temp=round(Tp(i)+0.5)-0.5;
    Tpcord=temp/0.5-6;
    if Tpcord<1
        Tpcord=1;
    end
    
    if or((Mdir(i)>=338),(Mdir(i)<=23))
    betacord=1;% _Head sea
    elseif or((Mdir(i)>=293),(Mdir(i)<=68))
    betacord=2; %Quartering head sea
    elseif or((Mdir(i)>=247),(Mdir(i)<=113))
    betacord=3;% Beam sea
    elseif or((Mdir(i)>=203),(Mdir(i)<=158))
    betacord=4; % Quartering following sea
    else
    betacord=5; % Following sea
    end
    if Hs(i)<=LHS_TMA(Tpcord,betacord)
        TMAteller=1+TMAteller;
        TMA_vector(i)=1;
    else
        TMA_vector(i)=0;
    end
    
    if Hs(i)<=LHS_JON(Tpcord,betacord)
        JONteller=1+JONteller;
    end
    if or(month(i)==12,month(i)<4);
        Wteller=Wteller+1;
        if Hs(i)<=LHS_TMA(Tpcord,betacord)
        TMAWteller=1+TMAWteller;
        end
    
        if Hs(i)<=LHS_JON(Tpcord,betacord)
        JONWteller=1+JONWteller;
        end
    end

end
   
avblty_TMA=TMAteller/l;
avblty_JON=JONteller/l;
avblty_JON_W=JONWteller/Wteller;
avblty_TMA_W=TMAWteller/Wteller;