%-------------------------------------------------------------%
% doublestdev.m                                               %
% Function that calculates the standard deviation of two load %
% spectrums and two fransfer functions linearly working under %
% the assumption that the stochasticprocess is ergodic, normal%
% distributed and narrow banded.                              %
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 16/03-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% HwW  - Transfer function 1                                  %
% SW   - Spectra      1                                       %
% HwS  - Transfer function  2                                 %
% SS   - Spectra   2                                          %
% omega - Corresponding frequency values                      %
% beta  - Corresponding headings                              %
%-------------------------------------------------------------%
% Output:                                                     %
% Standev  - The standard deviation                           % 
%-------------------------------------------------------------%

function Standev = doublestdev(HwW,SW,HwS,SS,omega,beta);
HwW=(transpose(HwW));
integW=abs(HwW.*HwW.*SW);
HwS=(transpose(HwS));
integS=abs(HwS.*HwS.*SS);
integ=integW+integS;
variance=trapz(omega,integ);
Standev=sqrt(variance);





end