%-------------------------------------------------------------%
% main.m                                                      %
%-------------------------------------------------------------%
%Script for calculating the limiting significant waveheight as%
%a function of peak period and wave direction and return      %
%useful statistics and graphics when compared to weather data.%
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 19/04-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% name         - VERES hydrodynamic data file name            %
% Racc         - Acceptable risk for failure during one access%
% Wavestat.dat - Metoccean file from Dogger Bank location 2   %
% Fbollard     - Available bollard force available for vessel %
% AccP         - Point of access, coordinate system have      %
%                origo in water plane, right handed           %
%                and positive x direction towards stern       %
% gma          - Parameter for the JONSWAP spectrum           %
% my           - Friction coefficient for vessel turbine      %
%                fender interaction                           %
% h            - Water depth [m]                              %
% Hsmax        - Maximum Hs one would like to consider [m]    %
% Rollmax      - Maximum roll angle acceptable [deg]          %
% Needs to be hardcoded into main.m                           %
%-------------------------------------------------------------%
% Output:                                                     %
% result.dat - File containing key results                    %
% plots      - Folder containing plots describing the LHS     %
%              ,excitation forces and RAOS                    %
%-------------------------------------------------------------%
% Self written functions:                                     %
% [A, B, C, M, Frao, beta , omega,RAOS]=readveres(name);      %
% [Stma Sjon Spm]= specter(Hs,Tp, h,omega, gma)               %
% []=plotter(Frao, beta, omega, LHS_TMA,LHS_JON,Heta,...      %
% Hneta,Rtransf,J1,J2,J3,RAOS)                                %
% [LHS_TMA LHS_JON dwTMA upTMA dwJON upJON]=limHs2(Heta,...   %
% Hneta,Racc,gma,h,omega,beta,Fbollard...                     %
% ,my,Hsmax,Rollmax,Rtransf,SHeta, SHneta)                    %
% [avblty_TMA avblty_JON avblty_JON_W avblty_TMA_W TMA_vector]%
% =availabily(LHS_TMA,LHS_JON)                                %
% Standev = stdev(Hw,S,omega);                                %
% Standev = doublestdev(HwW,SW,HwS,SS,omega,beta)             %
% [avblty_2spc_W avblty_2spc diffdec]=doublespec(Racc,Heta... %
% Hneta,h,my,Fbollard,omega,gma,beta,...                      %
% Rtransf,Rollmax,TMA_vector,SHeta, SHneta)                   %
% [Heta Hneta Rtransf J1 J2 J3 SHeta SHneta]=fendertransf...  %
%(A,M,C ,B,Frao,omega,beta,AccP,my)                           %
%[Bvisc]=viscdamp(my,A,B,C,M,RAOS,omega,Frao,viscKsi,h)       %
%[Fv]=viscousF(my,omega,Frao,beta,viscKsi)                    %
%-------------------------------------------------------------%
clc
clear all 
close all
format long
tic
%************* INPUT *********************************%
name='inputs/input_35_26.out';
AccP=[-12.24 0 3.8];
my=0.8; % Friction Coefficient
Fv=0;
viscKsi=1; % Assumed wave amplitude for calaculation of viscous damping and forces 
h=30; % Water depth
Racc=12*10^(-4); % Acceptable probability for failure during one access
gma=3.3; % Gammafactor (JONSWAP)
gmaS=5; % Gammafactor for representing swell
Fbollard=2*10^5;%[N]
plotting=0; %If plotting shall be done
dividedseacalc=0;% If divided sea state calculation shall be done
Hsmax=4; % MAximum Hs considered
Rollmaxdeg=10; %[deg]
Rollmax=Rollmaxdeg*pi/180; % Translating to [rad]
viscouseffects=1; % Parameter to determine weather viscous effects 
                  % in heave and pitch should be accounted for( Roll already is)                 
%*****************************************************%

[A, B, C, M, Frao, beta , omega,RAOS]=readveres(name);
if viscouseffects
   [Bvisc]=viscdamp(my,A,B,C,M,RAOS,omega,Frao,viscKsi,h);
   B=B+Bvisc;
   [Fv]=viscousF(my,omega,Frao,beta,viscKsi);
 
end
  [Heta Hneta Rtransf J1 J2 J3 SHeta SHneta Ptransf]=fendertransf(A,M,C,B,Frao,omega,beta,AccP,my,Fv);  

[LHS_TMA LHS_JON ]=limHs2(Heta,Hneta,...
    Racc,gma,h,omega,beta,Fbollard,my,Hsmax,Rollmax,Rtransf,SHeta, SHneta);
[avblty_TMA avblty_JON avblty_JON_W avblty_TMA_W TMA_vector]=availability(LHS_TMA,LHS_JON);


if plotting
plotter(Frao, beta, omega, LHS_TMA,LHS_JON,Heta, Hneta,Rtransf,J1,J2,J3,RAOS);

end

if dividedseacalc
[avblty_2spc_W avblty_2spc diffdec]=doublespec(Racc,Heta,Hneta,h,my,...
    Fbollard,omega,gma,beta,Rtransf,Rollmax,TMA_vector,gmaS,SHeta, SHneta);
end
t=toc
[a]=resultprint(avblty_2spc_W,avblty_2spc,diffdec,...
    avblty_TMA,avblty_JON,avblty_JON_W,avblty_TMA_W,t,Rollmaxdeg,Hsmax,my,Fbollard,Racc,AccP,gma,h);



