%-------------------------------------------------------------%
% plotter.m                                                   %
%-------------------------------------------------------------%
% Function that plots different data given by main.m          %
%-------------------------------------------------------------%
% Author: Heine Grtting                                      %
%-------------------------------------------------------------%
% Last edit: 27/02-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% omega - Wave frequencies                                    %
% Frao    Excitation force as function of omega and beta      %
% beta  - Wave heading                                        %
% Heta  - Transfer function for variable eta                  %
% Hneta - Transfer function for variable neta                 %
% LHS_TMA - Limiting Hs by using TMA spectrum                 %
% LHS_JON - Limiting Hs by using JONSWAP spectrum             %
% Rtransf - Roll transfer function                            %
% J1     - Transfer function for normal force in fender       %
% J2     - Transfer function for sideways force in fender     %
% J3     - Transfer function for vertical force in fender     %
% RAOS - 6*Nx6 responce amplitude operator                    %
%-------------------------------------------------------------%
% Output:                                                     %
% plots in the folder plots                                   %
%-------------------------------------------------------------%


function []=plotter(Frao, beta, omega, LHS_TMA,LHS_JON,Heta, Hneta,Rtransf,J1,J2,J3,RAOS)
Nfreq=length(omega);
Nhead=length(beta);
RAO=0;
F1exc=[]; % Matrixes containg the excitation forces in specified direction 
          % as function of omega and beta (Nfreq x Nbeta)
F2exc=[];
F3exc=[];
F4exc=[];
F5exc=[];
F6exc=[];
Tp=2:0.5:20;
if RAO==1;
for i=1:Nfreq
    for j=1:Nhead
    temp=(i-1)*6;
    F1exc(i,j)=real(Frao(temp+1,j));
    F2exc(i,j)=real(Frao(temp+2,j));
    F3exc(i,j)=real(Frao(temp+3,j));
    F4exc(i,j)=real(Frao(temp+4,j));
    F5exc(i,j)=real(Frao(temp+5,j));
    F6exc(i,j)=real(Frao(temp+6,j));
    end
end

%%%% plotting exciting forces %%%%%%%%%%%%%%%
h=figure(1);
plot(omega,F3exc(:,1),'blue')
hold on
plot(omega,F3exc(:,2),'red')
hold on
plot(omega,F3exc(:,3),'yellow')
hold on
plot(omega,F3exc(:,4),'green')
hold on
plot(omega,F3exc(:,5),'black')
legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
hold off
title('Excitation force transfer function in heave [N/m]')
xlabel('\omega [1/s]')
saveas(h,'plots/F3exc','jpg')

hh=figure(2);
plot(omega,F5exc(:,1),'blue')
hold on
plot(omega,F5exc(:,2),'red')
hold on
plot(omega,F5exc(:,3),'yellow')
hold on
plot(omega,F5exc(:,4),'green')
hold on
plot(omega,F5exc(:,5),'black')
legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
hold off
title('Excitation moment transfer function in pitch [Nm/m]')
xlabel('\omega [1/s]')
saveas(hh,'plots/F5exc','jpg')

hhh=figure(3);
plot(omega,F1exc(:,1),'blue')
hold on
plot(omega,F1exc(:,2),'red')
hold on
plot(omega,F1exc(:,3),'yellow')
hold on
plot(omega,F1exc(:,4),'green')
hold on
plot(omega,F1exc(:,5),'black')
legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
hold off
title('Excitation force transfer function in surge [N/m]')
xlabel('\omega [1/s]')
saveas(hhh,'plots/F1exc','jpg')

hhhh=figure(4);
plot(omega,F4exc(:,1),'blue')
hold on
plot(omega,F4exc(:,2),'red')
hold on
plot(omega,F4exc(:,3),'yellow')
hold on
plot(omega,F4exc(:,4),'green')
hold on
plot(omega,F4exc(:,5),'black')
legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
hold off
title('Excitation moment transfer function in roll [Nm/m]')
xlabel('\omega [1/s]')
saveas(hhh,'plots/F4exc','jpg')

hhhhh=figure(5);
plot(omega,F2exc(:,1),'blue')
hold on
plot(omega,F2exc(:,2),'red')
hold on
plot(omega,F2exc(:,3),'yellow')
hold on
plot(omega,F2exc(:,4),'green')
hold on
plot(omega,F2exc(:,5),'black')
legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
hold off
title('Excitation force transfer function in sway [N/m]')
xlabel('\omega [1/s]')
saveas(hhhhh,'plots/F2exc','jpg')

hhhhhh=figure(6);
plot(omega,F6exc(:,1),'blue')
hold on
plot(omega,F6exc(:,2),'red')
hold on
plot(omega,F6exc(:,3),'yellow')
hold on
plot(omega,F6exc(:,4),'green')
hold on
plot(omega,F6exc(:,5),'black')
legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
hold off
title('Excitation moment transfer function in yaw [Nm/m]')
xlabel('\omega [1/s]')
saveas(hhhhhh,'plots/F6exc','jpg')
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%******* plots of LHS and transfer function for fender reaction ********%
%f=figure(7);
%plot(omega,abs(Heta(:,1)),'blue')
%hold on
%plot(omega,abs(Heta(:,2)),'red')
%hold on
%plot(omega,abs(Heta(:,3)),'yellow')
%hold on
%plot(omega,abs(Heta(:,4)),'green')
%hold on
%plot(omega,abs(Heta(:,5)),'black')
%legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
%title('Transfer function for eta [N/m]');
%xlabel('wave frequency [rad/]');

%saveas(f,'plots/Etatransf','jpg')
%ff=figure(8);
%plot(omega,abs(Hneta(:,1)),'blue')
%hold on
%plot(omega,abs(Hneta(:,2)),'red')
%hold on
%plot(omega,abs(Hneta(:,3)),'yellow')
%hold on
%plot(omega,abs(Hneta(:,4)),'green')
%hold on
%plot(omega,abs(Hneta(:,5)),'black')
%title('Transfer function for neta [N/m]');
%xlabel('wave frequency [rad/]');
%legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')

%saveas(ff,'plots/Netatransf','jpg')
fff=figure(9);
Tp=2:0.5:20;
plot(Tp,LHS_JON(:,1),'blue')
hold on
plot(Tp,LHS_JON(:,2),'red')
hold on
plot(Tp,LHS_JON(:,3),'yellow')
hold on
plot(Tp,LHS_JON(:,4),'green')
hold on
plot(Tp,LHS_JON(:,5),'black')
title('Limiting significant waveheight [m](JONSWAP spectrum)');
xlabel('Peak period of seastate');
ylim([0 4])
xlim([4 20])
legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')

saveas(fff,'plots/JON_LHS','jpg')
ffff=figure(10);

plot(Tp,LHS_TMA(:,1),'blue')
hold on
plot(Tp,LHS_TMA(:,2),'red')
hold on
plot(Tp,LHS_TMA(:,3),'yellow')
hold on
plot(Tp,LHS_TMA(:,4),'green')
hold on
plot(Tp,LHS_TMA(:,5),'black')
title('Limiting significant waveheight [m](TMA spectrum)');
legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
xlabel('Peak period of seastate');
ylim([0 4])
xlim([4 20])
saveas(ffff,'plots/TMA_LHS','jpg')


%fffff=figure(11);
%plot(Tp,LHS_TMA(:,1));
%title('Limiting significant waveheight for head seas[m](TMA spectrum)');
%xlabel('Peak period of seastate');
%ylim([0 4]);
%xlim([2 20]);
%saveas(fffff,'plots/LHS_HEAD','jpg')

%rull=figure(12);
%plot(omega,abs(Rtransf(:,1)),'blue')
%hold on
%plot(omega,abs(Rtransf(:,2)),'red')
%hold on
%plot(omega,abs(Rtransf(:,3)),'yellow')
%hold on
%plot(omega,abs(Rtransf(:,4)),'green')
%hold on
%plot(omega,abs(Rtransf(:,5)),'black')
%title('Roll transfer function with vessel coupled to wind turbine');
%xlabel('Wave frequency [rad/s]');
%legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
%saveas(rull,'plots/Roll_transfer','jpg')




%fend1=figure(13);
%plot(omega,abs(J1(:,1)),'blue')
%hold on
%plot(omega,abs(J1(:,2)),'red')
%hold on
%plot(omega,abs(J1(:,3)),'yellow')
%hold on
%plot(omega,abs(J1(:,4)),'green')
%hold on
%plot(omega,abs(J1(:,5)),'black')
%legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
%hold off
%title('Fender normal force transfer function [N/m]')
%xlabel('\omega [1/s]')
%saveas(fend1,'plots/Fender_Norm_force','jpg')

%fend2=figure(14);
%plot(omega,abs(J2(:,1)),'blue')
%hold on
%plot(omega,abs(J2(:,2)),'red')
%hold on
%plot(omega,abs(J2(:,3)),'yellow')
%hold on
%plot(omega,abs(J2(:,4)),'green')
%hold on
%plot(omega,abs(J2(:,5)),'black')
%legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
%hold off
%title('Fender sideways force transfer function [N/m]')
%saveas(fend2,'plots/Fender_horiz_force','jpg')

%fend3=figure(15);
%plot(omega,abs(J3(:,1)),'blue')
%hold on
%plot(omega,abs(J3(:,2)),'red')
%hold on
%plot(omega,abs(J3(:,3)),'yellow')
%hold on
%plot(omega,abs(J3(:,4)),'green')
%hold on
%plot(omega,abs(J3(:,5)),'black')
%legend('0 deg', '45 deg' ,'90 deg' ,'135 deg' ,'180 deg')
%hold off
%title('Fender vertical force transfer function [N/m]')
%saveas(fend3,'plots/Fender_vert_force','jpg')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%Plots of RAOS%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%RAOs=figure(16);
%plot(omega,RAOS(1:Nfreq,1),'blue')
%hold on
%plot(omega,RAOS(Nfreq+1:2*Nfreq,1),'red')
%hold on
%plot(omega,RAOS(2*Nfreq+1:3*Nfreq,1),'yellow')
%legend('0 deg', '45 deg' ,'90 deg' );
%hold off
%title('Surge motion RAO [-]')
%saveas(RAOs,'plots/surgeRAOS','jpg')

%RAOh=figure(17);
%plot(omega,RAOS(1:Nfreq,3),'blue')
%hold on
%plot(omega,RAOS(Nfreq+1:2*Nfreq,3),'red')
%hold on
%plot(omega,RAOS(2*Nfreq+1:3*Nfreq,3),'yellow')
%legend('0 deg', '45 deg' ,'90 deg' );
%hold off
%title('Heave motion RAO [-]')
%saveas(RAOh,'plots/heaveRAOS','jpg')
if RAO==1
RAOr=figure(18);
plot(omega,RAOS(1:Nfreq,4),'blue')
hold on
plot(omega,RAOS(Nfreq+1:2*Nfreq,4),'red')
hold on
plot(omega,RAOS(2*Nfreq+1:3*Nfreq,4),'yellow')
legend('0 deg', '45 deg' ,'90 deg' );
hold off
title('Roll motion RAO [-]')
saveas(RAOs,'plots/rollRAOS','jpg')

RAOp=figure(19);
plot(omega,RAOS(1:Nfreq,5),'blue')
hold on
plot(omega,RAOS(Nfreq+1:2*Nfreq,5),'red')
hold on
plot(omega,RAOS(2*Nfreq+1:3*Nfreq,5),'yellow')
legend('0 deg', '45 deg' ,'90 deg' );
hold off
title('Pitch motion RAO [-]')
saveas(RAOs,'plots/pitchRAOS','jpg')

fffff=figure(20);
X=fliplr(2*pi./Tp);
Y=fliplr(LHS_TMA(:,1));
plot(X,Y);
title('Limiting significant waveheight for head seas[m](TMA spectrum)');
xlabel('Peak frequency of seastate[rad/s]');
ylim([0 4]);
xlim([0 3.14]);
saveas(fffff,'plots/LHS_HEAD','jpg')
end
end