%-------------------------------------------------------------%
% readveres.m                                                 %
%-------------------------------------------------------------%
% Function for reading file from Veres of type input.out      %
% Frequency dependent added mass and damping terms , mass mat-%
% rix , hydrostatic stiffness matrix together with transfer   %
% function for excitation forces for different frequencies    %
% and directions is read from the file generated by VERES to  %
% be used in a function written later that will calculate the %
% limiting significant waveheight for access of a offshore    %
% wind turbine.                                               %
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 27/02-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% A VERES result file of format input.out                     %
%-------------------------------------------------------------%
% Output:                                                     %
% N is number of frequencies investigated and M is number of  %
% of directions.                                              %
% M - 6x6 mass matrix                                         %
% C - 6x6 hydrostatic stiffness matrix                        %
% A - 6*Nx6 added mass matrices                               %
% B - 6*Nx6 damping matrices                                  %
% Frao - 6*NxM                                                %
% omega - Nx1 vector containing frequencies                   %
% beta - Mx1 vector containing headings                       %
% RAOS - 6*Nx6 responce amplitude operator                    %
%-------------------------------------------------------------%

function [A, B, C, M, Frao, beta , omega,RAOS]=readveres(name)
A=[];
B=[];
C=[];
M=[];
Frao=[];
RAO=[];
fid=fopen(name,'r');

run=1;
teller=1;
while run
temp=fgetl(fid);
teller=teller+1;
if strcmpi(temp,'     WAVE ENVIRONMENT')
   for i=1:4
       dummy=fgets(fid);
   end
   temp2=fgetl(fid);
   temp3=strsplit(temp2,'=');
   Nfreq=str2double(temp3(2))% NUMBER OF FREQUENSIES INVESTIGATED
   %A=zeros(Nfreq*6,6);
   %B=zeros(Nfreq*6,6);
   for i=1:2
       dummy=fgets(fid);
   end
   temp2=fgetl(fid);
   temp3=strsplit(temp2,'=');
   Nhead=str2double(temp3(2))% NUMBER OF HEADINGS INVESTIGATED
   for i=1:10
       dummy=fgets(fid);
   end
   for i=1:Nfreq
   temp2=strsplit(fgetl(fid));
   temp3=str2double(temp2);
   omega(i)=temp3(3);
   Wnum(i)=temp(5); %%% Wave numbers
   end
   for i=1:7
       dummy=fgets(fid);
   end
   
   temp2=str2double(strsplit(fgetl(fid)));
   beta=temp2(2:(Nhead+1));
   
   
   
end

if strcmpi(temp,'     Mass matrix:')
   for i=1:6
   temp2=strsplit(fgetl(fid));
   temp3=str2double(temp2);
   M(i,:)=temp3(2:7); %READING MASS MATRIX
   end
   for i=1:3
       dummy=fgets(fid);
   end
   for i=1:6
   temp2=strsplit(fgetl(fid));
   temp3=str2double(temp2);
   C(i,:)=temp3(2:7); %READING HYDRODYNAMIC STIFFNESS MATRIX
   end
end 
if strcmpi(temp,'     ADDED MASS AND DAMPING MATRICES')
    for i=1:Nhead
        for j=1:Nfreq
            for n=1:11
            dummy=fgets(fid)  ; 
            end
            temp1=(j-1)*6;
            for n=1:6
            temp2=temp1+n;
            temp3=strsplit(fgetl(fid));
            temp4=str2double(temp3);
            A(temp2,:)=temp4(2:7); 
            end
            dummy=fgets(fid);
            dummy=fgets(fid); 
            for n=1:6
            temp2=(j-1)*6+n;
            temp3=strsplit(fgetl(fid));
            temp4=str2double(temp3);
            B(temp2,:)=temp4(2:7); 
            end
            for n=1:14
            dummy=fgets(fid)  ; 
            end
            temp3=strsplit(fgetl(fid));
            temp4=str2double(temp3);
            Frao(1+temp1,i)=complex(temp4(2),temp4(3));
            Frao(2+temp1,i)=complex(temp4(4),temp4(5));
            Frao(3+temp1,i)=complex(temp4(6),temp4(7));
            for n=1:5
            dummy=fgets(fid)  ; 
            end
            temp3=strsplit(fgetl(fid));
            temp4=str2double(temp3);
            Frao(4+temp1,i)=complex(temp4(2),temp4(3));
            Frao(5+temp1,i)=complex(temp4(4),temp4(5));
            Frao(6+temp1,i)=complex(temp4(6),temp4(7));
            for n=1:18
            dummy=fgets(fid)  ;   
            end

        end
    end
    
end
if strcmpi(temp,'     NON-DIMENSIONAL MOTION TRANSFER FUNCTION') 
   for n=1:22
      dummy=fgets(fid) ;   
   end
   %%%%%%%%%%%%%%%%%%%%%  0 deg %%%%%%%%%%%%%%%%%%%%%%
   for n=1:Nfreq
           temp3=strsplit(fgetl(fid));
           temp4=str2double(temp3);
            RAOS(n,1)=temp4(3);
            RAOS(n,2)=temp4(5);
            RAOS(n,3)=temp4(7);
       
   end
   for n=1:5
      dummy=fgets(fid)  ;   
   end
  for n=1:Nfreq
           temp3=strsplit(fgetl(fid));
           temp4=str2double(temp3);
            RAOS(n,4)=temp4(3);
            RAOS(n,5)=temp4(5);
            RAOS(n,6)=temp4(7);
       
  end
   for n=1:27
          dummy=fgets(fid)  ;   
   end
   %%%%%%%%%%%%%%% 45 deg %%%%%%%%%%%%%%%%%%%%
      for n=1:Nfreq
           temp3=strsplit(fgetl(fid));
           temp4=str2double(temp3);
            RAOS(Nfreq+n,1)=temp4(3);
            RAOS(Nfreq+n,2)=temp4(5);
            RAOS(Nfreq+n,3)=temp4(7);
       
   end
   for n=1:5
      dummy=fgets(fid)  ;   
   end
  for n=1:Nfreq
           temp3=strsplit(fgetl(fid));
           temp4=str2double(temp3);
            RAOS(Nfreq+n,4)=temp4(3);
            RAOS(Nfreq+n,5)=temp4(5);
            RAOS(Nfreq+n,6)=temp4(7);
       
  end
   for n=1:27
          dummy=fgets(fid)  ;   
   end
  %%%%%%%%%%%%%%%%%%%%%%%%%%% 90 deg %%%%%%%%%%%%%%%%%%%%%%
        for n=1:Nfreq
           temp3=strsplit(fgetl(fid));
           temp4=str2double(temp3);
            RAOS(2*Nfreq+n,1)=temp4(3);
            RAOS(2*Nfreq+n,2)=temp4(5);
            RAOS(2*Nfreq+n,3)=temp4(7);
       
   end
   for n=1:5
      dummy=fgets(fid)  ;   
   end
  for n=1:Nfreq
           temp3=strsplit(fgetl(fid));
           temp4=str2double(temp3);
            RAOS(2*Nfreq+n,4)=temp4(3);
            RAOS(2*Nfreq+n,5)=temp4(5);
            RAOS(2*Nfreq+n,6)=temp4(7);
       
  end
  
   run=0; % QUITING WHILE LOOP
end


end

fclose(fid)





end