% Function that calculates additional quadratic damping in    %
% heave and pitch, linearize it and and returns an additional %
% damping matrix.                                             %
% viscdamp.m
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 17/03-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% M     - 6x6 mass matrix                                     %
% C     - 6x6 hydrostatic stiffness matrix                    %
% A     - 6*Nx6 added mass matrices                           %
% B     - 6*Nx6 damping matrices                              %
% Frao  - 6*NxM                                               %
% omega - Nx1 vector containing frequensies                   %
% beta  - Mx1 vector containing headings                      %
% AccP  - Point of access                                     %
%-------------------------------------------------------------%
% Output:                                                     %
% Bvisc= Additional viscous damping matrix                    %
%-------------------------------------------------------------%
function [Bvisc]=viscdamp(Xg,A,B,C,M,RAOS,omega,Frao,ksiA,h)
a=Xg;
viscplot=1;
[HxP WxP x]=Swathdesign(a);
Cd=1.1;   % # Cengel and Cimbala for this kind of form and aspect ratio
amp=ksiA;  % This value has to be assumed, and result will depend on this!
Nfreq=length(omega);
img=1i;
Bvisc=zeros(6*Nfreq,6);
RAOS2=RAOS(1:Nfreq,:);
Nponts=length(WxP);
DX=x(2)-x(1);

rho=1025;%% Density of seawater
g=9.81;
teller=0;
for i=1:Nfreq
    
    temp=(i-1)*6;
    diff=1;
    krav=0.1;
    tempA=A((temp+1):(temp+6), 1:6); % Added mass matrix for given frequency
    tempB=B((temp+1):(temp+6), 1:6); % Damping matrix for given frequency
    tempFrao=amp*Frao((temp+1):(temp+6), 1); % Excitation force Rao for given frequency
    B33(i)=0;
    B55(i)=0;
    RAO=inv(-omega(i)^2*(tempA+M)+omega(i)*img*tempB+C)*tempFrao;
    RAOold=RAO;
    teller=0;
    while diff>krav

    
    Mamp=abs(RAO(3))*amp;
    Cdstar=0.5*rho*Cd*Mamp*8*omega(i)/(3*pi);%%% Linearization, ref Faltinsen page 97
    for j=1:Nponts
        b33(j)=2*Cdstar*WxP(j)*DX;% two pontoons

    end
    B33(i)=sum(b33);
    tempB(3,3)=B(temp+3, 3)+B33(i);
    RAOnew=inv(-omega(i)^2*(tempA+M)+omega(i)*img*tempB+C)*tempFrao;
    diff=abs(abs(RAOnew(3))-abs(RAO(3)));
    teller=teller+1;
    RAO=RAOnew;
    end
    Bvisc(temp+3,3)=B33(i);
    diff=1;
    krav=0.05;
    while diff>krav

    k=wavenum(omega(i),h);
    Mamp=k*abs(RAO(5))*amp;
    Cdstar=0.5*rho*Cd*Mamp*8*omega(i)/(3*pi);%%% Linearization, ref Faltinsen page 97
    for j=1:Nponts
        b55(j)=2*Cdstar*WxP(j)*DX*x(j)^3;
    end
    B55(i)=sum(b55);
    tempB(5,5)=B(temp+5, 5)+B55(i);
    RAOnew=inv(-omega(i)^2*(tempA+M)+omega(i)*img*tempB+C)*tempFrao;
    diff=abs(abs(RAOnew(5))-abs(RAOold(5)));
    teller=teller+1;
    w=omega(i);
    RAOold=RAOnew;
    end
    
    
    
    Bvisc(temp+5,5)=B55(i);
    RAOS2(i,1:6)=abs(RAOnew);
    
end 







end
