%-------------------------------------------------------------%
% viscousF.m                                                  %
%-------------------------------------------------------------%
% Function that estimates viscous excitation force in heave   %
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 2/05-15                                          %
%-------------------------------------------------------------%
% Input:                                                      %
% Frao    - Excitation force RAO                              %
% omega   - Wave frequencies                                  % 
% beta    - Wave headings                                     %
% Xg      - Poition of COG compared to LPP/2                  %
%-------------------------------------------------------------%
% Output:                                                     %
% Fv      - Viscous excitation force in heave as depending in %
%           frequency and direction. 6*NxM matrix             %
%-------------------------------------------------------------%
function [Fv]=viscousF(Xg,omega,Frao,beta,ksiA)
a=Xg;
viscplot=0;
[HxP WxP x]=Swathdesign(a);
Nfreq=length(omega);
Nhead=length(beta);
Cd=1.1;
rho=1025;%% Density of seawater
g=9.81;
Nponts=length(WxP);
DX=x(2)-x(1);
z=-1.5;
h=30;
img=1i;
Fv=zeros(6*Nfreq,Nhead);
for n=1:Nhead
for i=1:Nfreq
    temp=(i-1)*6;
    if omega(i)>1.57
   
    end
    k(i)=wavenum(omega(i),h);

    Wavelength(i)=2*pi/k(i);
   kx=cosd(beta(n))*k(i);
   ky=sind(beta(n))*k(i);
   F3amp=0;
    for j=1:Nponts
        WspeedAmpleft=ksiA*omega(i)*(sinh(k(i)*(z+h))/sinh(k(i)*h))*cos(-kx*x(j)-ky*4);
        WspeedAmpright=ksiA*omega(i)*(sinh(k(i)*(z+h))/sinh(k(i)*h))*cos(-kx*x(j)+ky*4);
        Cdstarleft=ksiA*0.5*rho*Cd*WspeedAmpleft*8*omega(i)/(3*pi);
        Cdstarright=ksiA*0.5*rho*Cd*WspeedAmpright*8*omega(i)/(3*pi);
        F3amp(j)=(Cdstarleft+Cdstarright)*WxP(j)*DX;%        % Taking into account varying fluid velocity and varying diameter along pontoon 
        % lin=linearization factor
    end
    Fv(temp+3,n)=sum(F3amp)/ksiA-img*90; % Taking care of the phase
    F3(i,n)=sum(F3amp);
end
end

end
