%-------------------------------------------------------------%
% wavenum                                                     %
%-------------------------------------------------------------%
% Function that iterates it way to the correct wave number    %
% given frequency and water depth with 10^-6 accuracy with    %
% Newtons method                                              %
%-------------------------------------------------------------%
% Author: Heine Grtting                                      %
%-------------------------------------------------------------%
% Last edit: 27/02-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% omega - Wave frequency                                      %
% h     - Water depth                                         Y
%-------------------------------------------------------------%
% Output:                                                     %
% correct wave number                                         %
%-------------------------------------------------------------%
function [k]=wavenum(omega,h);
g=9.81;
krav=10^-6;
    ktemp=omega*omega/g;
    diff=abs(omega*omega-g*ktemp*tanh(h*ktemp));
    while diff>krav % iterating with Newtons method
        Ftemp=g*ktemp*tanh(h*ktemp)-omega*omega;
        ftemp=g*tanh(h*ktemp)+g*h*ktemp*(sech(h*ktemp)^2);
     ktemp=ktemp-Ftemp/ftemp   ;
     diff=abs(omega*omega-g*ktemp*tanh(h*ktemp));
    end
    k=ktemp;
end